@@ -3,6 +3,9 @@ import copy
 import cv2
 import numpy as np
 
+from pyfld.Exceptions import LineNotFound, PointChainNotFound
+
+
 class Point(list):
     def __init__(self, x, y):
         super().__init__([x,y])
@@ -99,7 +102,9 @@ class FastLineDetector:
         """
         image = np.array(image)
         segments = self.line_detection(image)
-        return segments
+        if segments == []:
+            raise LineNotFound("The image has no line segments")
+        return np.array(segments).T
 
     def line_detection(self, src):
         self._h, self._w = src.shape
@@ -182,7 +187,8 @@ class FastLineDetector:
         """
         point_chain = []
         if np.all(img == 0):
-            return point_chain
+            raise PointChainNotFound("The image has no point chain")
+
         # rs, cs = np.where(img != 0)
         # for r, c in zip(rs, cs):
         for r in range(img.shape[0]):
